-------------------------------------------------------------------------------
-- ElvUI Chat Tweaks By Lockslap (US, Bleeding Hollow)
-- <Borderline Amazing>, http://ba-guild.com
-- Based on functionality provided by Prat and/or Chatter
-------------------------------------------------------------------------------
local Module	= ElvUI_ChatTweaks:NewModule("Color Rolls")
local L			= LibStub("AceLocale-3.0"):GetLocale("ElvUI_ChatTweaks")
Module.name		= L["Color Rolls"]

local format	= string.format
local ROLL_MSG	= "(.+) rolls (.+) %((.+)%-(.+)%)"

local db, options
local defaults = {
	profile	= {
		colorRolls	= true,
		rollColor	= {r = 1.0, g = 1.0, b = 0},	-- yellow
		colorYours	= true,
		yourColor	= {r = 0, g = 1.0, b = 1.0},	-- blue/green
		colorWin	= true,
		winColor	= {r = 0, g = 1.0, b = 0},		-- green
		colorLoss	= true,
		lossColor	= {r = 1.0, g = 0, b = 0},		-- red
	}
}

local function ColorMessage(color, message)
	return ("|cff%02x%02x%02x%s|r"):format(color.r * 255, color.g * 255, color.b * 255, message)
end

local function CaptureRolls(self, event, message, ...)
	if not message:match(ROLL_MSG) then return false end
	
	local who, roll, _, _ = message:match(ROLL_MSG)
	roll = tonumber(roll)
	if who:lower() == UnitName("player"):lower() then
		if roll == 1 then
			-- you lost
			if db.colorLoss then
				return false, ColorMessage(db.lossColor, message), ...
			else
				return false, message, ...
			end
		else
			-- a regular roll of yours
			if db.colorYours then
				return false, ColorMessage(db.yourColor, message), ...
			else
				return false, message, ...
			end
		end
	else
		if roll == 1 then
			-- you win (if you're rolling this person)
			if db.colorWin then
				return false, ColorMessage(db.winColor, message), ...
			else
				return false, message, ...
			end
		else
			-- regular roll by others
			if db.colorRolls then
				return false, ColorMessage(db.rollColor, message), ...
			else
				return false, message, ...
			end
		end
	end
end

function Module:OnEnable()
	ChatFrame_AddMessageEventFilter("CHAT_MSG_SYSTEM", CaptureRolls)
end

function Module:OnDisable()
	ChatFrame_RemoveMessageEventFilter("CHAT_MSG_SYSTEM", CaptureRolls)
end

function Module:OnInitialize()
	self.db = ElvUI_ChatTweaks.db:RegisterNamespace("ColorRolls", defaults)
	db = self.db.profile
end

function Module:Info()
	return L["Color rolls differently to make tracking the roll game easier on the eyes."]
end

function Module:GetOptions()
	if not options then
		options = {
			colorRolls		= {
				type		= "toggle",
				order		= 13,
				name		= L["Color Rolls"],
				desc		= L["Color regular rolls by others."],
				get			= function() return db.colorRolls end,
				set			= function(_, value) db.colorRolls = value end,
			},
			rollColor		= {
				type		= "color",
				order		= 14,
				width		= "double",
				name		= L["Roll Color"],
				desc		= L["Color of other's rolls."],
				disabled	= function() return not db.colorRolls end,
				get			= function() return db.rollColor.r, db.rollColor.g, db.rollColor.b end,
				set			= function(_, r, g, b) db.rollColor.r = r; db.rollColor.g = g; db.rollColor.b = b; end,
			},
			colorYours		= {
				type		= "toggle",
				order		= 15,
				name		= L["Color Your Rolls"],
				desc		= L["Color your rolls to set them apart."],
				get			= function() return db.colorYours end,
				set			= function(_, value) db.colorYours = value end,
			},
			yourColor		= {
				type		= "color",
				order		= 16,
				width		= "double",
				name		= L["Your Color"],
				desc		= L["Color to use for your rolls."],
				disabled	= function() return not db.colorYours end,
				get			= function() return db.yourColor.r, db.yourColor.g, db.yourColor.b end,
				set			= function(_, r, g, b) db.yourColor.r = r; db.yourColor.g = g; db.yourColor.b = b; end,
			},
			colorWin		= {
				type		= "toggle",
				order		= 17,
				name		= L["Color Win"],
				desc		= L["Color a roll game win, aka when someone else rolls a one (1)."],
				get			= function() return db.colorWin end,
				set			= function(_, value) db.colorWin = value end,
			},
			winColor		= {
				type		= "color",
				order		= 18,
				width		= "double",
				name		= L["Win Color"],
				desc		= L["Color to designate a roll game win."],
				disabled	= function() return not db.colorWin end,
				get			= function() return db.winColor.r, db.winColor.g, db.winColor.b end,
				set			= function(_, r, g, b) db.winColor.r = r; db.winColor.g = g; db.winColor.b = b; end,
			},
			colorLoss		= {
				type		= "toggle",
				order		= 19,
				name		= L["Color Loss"],
				desc		= L["Color a roll game loss, aka when you roll a one (1)."],
				get			= function() return db.colorLoss end,
				set			= function(_, value) db.colorLoss = value end,
			},
			lossColor		= {
				type		= "color",
				order		= 20,
				width		= "double",
				name		= L["Loss Color"],
				desc		= L["Color to designate a roll game loss."],
				disabled	= function() return not db.colorLoss end,
				get			= function() return db.lossColor.r, db.lossColor.g, db.lossColor.b end,
				set			= function(_, r, g, b) db.lossColor.r = r; db.lossColor.g = g; db.lossColor.b = b; end,
			}
		}
	end
	return options
end